@@ -45,6 +45,7 @@
 #include "cardinfo.h"
 #include "timeanddate.h"
 #include "users/passwd.h"
+#include "network.h"
 
 static GtkWidget *passwd_entry;
 static int retv;
@@ -87,16 +88,25 @@ update_dns_server (const gchar * server)
 void
 update_time_from_net (const gchar * server)
 {
+	
+	if (setvbuf(nsreturn,NULL,_IONBF,0) != 0) 
+		fprintf(stderr,"gpe-conf: error setting buffer size!");
+	
 	char *tstr = g_strdup_printf ("ntpdate -b %s", server);
 	if (system(tstr))
 	{
 		fprintf (stderr, "failed to execute ntpdate\n");
+		fprintf(nsreturn,"<failed>\n");
 	}
-	else			// if ok, update rtc time
+	else			/* if ok, update rtc time */
 	{
+		fprintf(nsreturn,"<success>\n");
+		system("/sbin/hwclock --systohc");
 		system ("echo > /var/spool/at/trigger");
 	}
 	g_free(tstr);
+	fflush(nsreturn);
+	fsync(nsreturnfd);
 }
 
 
@@ -336,11 +346,11 @@ suidloop (int write, int read)
 					time_t t;
 					fscanf (in, "%ld", &t);
 					if (stime (&t) == -1)
-						fprintf (stderr,
-							 "Error while setting the time: %d\n",
-							 errno);
+						fprintf (stderr, "Error while setting the time: %d\n",
+						         errno);
 					else	// if ok, update rtc time
 					{
+						system("/sbin/hwclock --systohc");
 						system ("echo > /var/spool/at/trigger");
 					}
 				}
@@ -359,13 +369,7 @@ suidloop (int write, int read)
 				else if (strcmp (cmd, "CPIF") == 0)  // installs a new interfaces file
 				{
 					fscanf (in, "%100s", arg2);	// to forget soon...
-					strcpy (arg1, "/tmp/interfaces");
-					strcpy (arg2, "/etc/network/interfaces");
-					system ("/etc/init.d/networking stop");
-					system_printf ("/bin/cp %s %s", arg1, arg2);
-					system_printf ("chmod 0644 %s", arg2);
-					system_printf ("/bin/rm -f %s", arg1);
-					system ("/etc/init.d/networking start");
+					copy_new_interfaces();
 				}
 				else if (strcmp (cmd, "CPOI") == 0)  // rewrites owner information data
 				{
@@ -380,6 +384,7 @@ suidloop (int write, int read)
 				}
 				else if (strcmp (cmd, "XCAL") == 0)  // runs screen calibration tool
 				{
+					fscanf (in, "%100s", arg2);
 					system ("/usr/bin/xtscal");
 				}
 				else if (strcmp (cmd, "STZO") == 0)  // changes the timezone setting 
